==> panel_material_ui-0.0.1b9.tar.gz: panel_material_ui-0.0.1b9/README.md <==
# ✨ Welcome to panel-material-ui

<table>
<tbody>
<tr>
<td>Downloads</td>
<td><a href="https://pypistats.org/packages/panel-material-ui"><img src="https://img.shields.io/pypi/dm/panel-material-ui?label=pypi" alt="PyPi Downloads" /></a></td>
</tr>
<tr>
<td>Build Status</td>
<td><a href="https://github.com/panel-extensions/panel-material-ui/actions/workflows/test.yaml?query=branch%3Amain"><img src="https://github.com/panel-extensions/panel-material-ui/workflows/tests/badge.svg?query=branch%3Amain" alt="Linux/MacOS Build Status"></a></td>
</tr>
<tr>
<td>Coverage</td>
<td><a href="https://codecov.io/gh/panel-extensions/panel-material-ui"><img src="https://codecov.io/gh/panel-extensions/panel-material-ui/branch/main/graph/badge.svg" alt="codecov"></a></td>
</tr>
<tr>
<td>Latest dev release</td>
<td><a href="https://github.com/panel-extensions/panel-material-ui/tags"><img src="https://img.shields.io/github/v/tag/panel-extensions/panel-material-ui.svg?label=tag&amp;colorB=11ccbb" alt="Github tag"></a> <a href="https://holoviz-dev.github.io/panel-material-ui/"><img src="https://img.shields.io/website-up-down-green-red/https/holoviz-dev.github.io/panel-material-ui.svg?label=dev%20website" alt="dev-site"></a></td>
</tr>
<tr>
<td>Latest release</td>
<td><a href="https://github.com/panel-extensions/panel-material-ui/releases"><img src="https://img.shields.io/github/release/panel-extensions/panel-material-uiel.svg?label=tag&amp;colorB=11ccbb" alt="Github release"></a> <a href="https://pypi.python.org/pypi/panel-material-ui"><img src="https://img.shields.io/pypi/v/panel-material-ui.svg?colorB=cc77dd" alt="PyPI version"></a> <a href="https://anaconda.org/pyviz/panel-material-ui"><img src="https://img.shields.io/conda/v/pyviz/panel-material-ui.svg?label=conda%7Cpyviz&colorB=4488ff&amp;style=flat" alt="panel version"></a> <a href="https://anaconda.org/conda-forge/panel-material-ui"><img src="https://img.shields.io/conda/v/conda-forge/panel-material-ui.svg?label=conda%7Cconda-forge&amp;colorB=4488ff" alt="conda-forge version"></a> <a href="https://anaconda.org/anaconda/panel-material-ui"><img src="https://img.shields.io/conda/v/anaconda/panel-material-ui.svg?label=conda%7Cdefaults&amp;style=flat&amp;colorB=4488ff" alt="defaults version"></a></td>
</tr>
<tr>
<td>Docs</td>
<td><a href="https://github.com/panel-extensions/panel-material-ui/tree/gh-pages"><img src="https://img.shields.io/github/last-commit/panel-extensions/panel-material-ui/gh-pages.svg" alt="gh-pages"></a> <a href="https://panel-extensions.github.io/panel-material-ui/"><img src="https://img.shields.io/website-up-down-green-red/https/panel-extensions.github.io/panel-material-ui.svg" alt="site"></a>
</td>
</tr>
<tr>
<td>Support</td>
<td><a href="https://discourse.holoviz.org/"><img src="https://img.shields.io/discourse/status?server=https%3A%2F%2Fdiscourse.holoviz.org" alt="Discourse"></a> <a href="https://discord.gg/rb6gPXbdAr"><img alt="Discord" src="https://img.shields.io/discord/1075331058024861767"></a>
</td>
</tr>
</tbody>
</table>

Welcome to Panel Material UI – a library that brings the sleek look and comprehensive component set of Material UI into the world of Panel.

## Why Panel Material UI?

- **Consistent Look & Feel**
  Panel Material UI leverages Material UI’s design principles to give your Panel dashboards and applications a modern, cohesive style.

- **Easy Theming & Styling**
  Take control of your UI using Material UI’s theming concepts. Customize colors, typography, spacing, and more with minimal configuration. Quickly modify styling for one-off situations using the sx parameter or create global overrides via theme_config.

- **Seamless Dark Mode**
  Effortlessly toggle between light and dark palettes. Whether you want a permanently dark dashboard, a user-driven switch, or to match the system preference, Panel Material UI has you covered.

- **Familiar Panel API**
All components provide a similar API to native Panel widgets, ensuring a smooth developer experience. Pass parameters, bind widgets to reactive functions, and lay them out using Panel’s layout system.

- **Rich Component Set**
Access a growing collection of Material UI–inspired components (Buttons, Sliders, Cards, Dialogs, and more), all adapted to work with Panel. Spend less time building UI from scratch and more time showcasing your data.

- **Powerful Theming Inheritance**
  Define a theme at a parent level and let it automatically apply to child components without extra configuration, reducing repetitive code while maintaining consistent branding.

## Installation

Install `panel-material-ui` via `pip`:

```bash
pip install panel-material-ui
```

## ❤️ Contributions

Contributions and co-maintainers are very welcome! Please submit issues or pull requests to the [GitHub repository](https://github.com/panel-extensions/panel-material-ui). Check out the [DEVELOPER_GUIDE](DEVELOPER_GUIDE.md) for more information.

==> panel_material_ui-0.1.2.tar.gz: panel_material_ui-0.1.2/README.md <==
# ✨ Welcome to panel-material-ui

<table>
<tbody>
<tr>
<td>Downloads</td>
<td><a href="https://pypistats.org/packages/panel-material-ui"><img src="https://img.shields.io/pypi/dm/panel-material-ui?label=pypi" alt="PyPi Downloads" /></a></td>
</tr>
<tr>
<td>Build Status</td>
<td><a href="https://github.com/panel-extensions/panel-material-ui/actions/workflows/test.yaml?query=branch%3Amain"><img src="https://github.com/panel-extensions/panel-material-ui/workflows/tests/badge.svg?query=branch%3Amain" alt="Linux/MacOS Build Status"></a></td>
</tr>
<tr>
<td>Coverage</td>
<td><a href="https://codecov.io/gh/panel-extensions/panel-material-ui"><img src="https://codecov.io/gh/panel-extensions/panel-material-ui/branch/main/graph/badge.svg" alt="codecov"></a></td>
</tr>
<tr>
<td>Latest dev release</td>
<td><a href="https://github.com/panel-extensions/panel-material-ui/tags"><img src="https://img.shields.io/github/v/tag/panel-extensions/panel-material-ui.svg?label=tag&amp;colorB=11ccbb" alt="Github tag"></a> <a href="https://holoviz-dev.github.io/panel-material-ui/"><img src="https://img.shields.io/website-up-down-green-red/https/holoviz-dev.github.io/panel-material-ui.svg?label=dev%20website" alt="dev-site"></a></td>
</tr>
<tr>
<td>Latest release</td>
<td><a href="https://github.com/panel-extensions/panel-material-ui/releases"><img src="https://img.shields.io/github/release/panel-extensions/panel-material-uiel.svg?label=tag&amp;colorB=11ccbb" alt="Github release"></a> <a href="https://pypi.python.org/pypi/panel-material-ui"><img src="https://img.shields.io/pypi/v/panel-material-ui.svg?colorB=cc77dd" alt="PyPI version"></a> <a href="https://anaconda.org/conda-forge/panel-material-ui"><img src="https://img.shields.io/conda/v/conda-forge/panel-material-ui.svg?label=conda%7Cconda-forge&amp;colorB=4488ff" alt="conda-forge version"></a> <a href="https://anaconda.org/anaconda/panel-material-ui"><img src="https://img.shields.io/conda/v/anaconda/panel-material-ui.svg?label=conda%7Cdefaults&amp;style=flat&amp;colorB=4488ff" alt="defaults version"></a></td>
</tr>
<tr>
<td>Docs</td>
<td><a href="https://github.com/panel-extensions/panel-material-ui/tree/gh-pages"><img src="https://img.shields.io/github/last-commit/panel-extensions/panel-material-ui/gh-pages.svg" alt="gh-pages"></a> <a href="https://panel-extensions.github.io/panel-material-ui/"><img src="https://img.shields.io/website-up-down-green-red/https/panel-extensions.github.io/panel-material-ui.svg" alt="site"></a>
</td>
</tr>
<tr>
<td>Support</td>
<td><a href="https://discourse.holoviz.org/"><img src="https://img.shields.io/discourse/status?server=https%3A%2F%2Fdiscourse.holoviz.org" alt="Discourse"></a> <a href="https://discord.gg/rb6gPXbdAr"><img alt="Discord" src="https://img.shields.io/discord/1075331058024861767"></a>
</td>
</tr>
</tbody>
</table>

Welcome to Panel Material UI – a library that brings the sleek design and comprehensive component set of [Material UI](https://mui.com/material-ui/) into the world of Panel.

<a href="https://panel-material-ui.holoviz.org/">
  <picture>
    <source media="(prefers-color-scheme: dark)" srcset="https://github.com/panel-extensions/panel-material-ui/raw/main/doc/_static/panel-material-ui-components-dark.png">
    <img src="https://github.com/panel-extensions/panel-material-ui/raw/main/doc/_static/panel-material-ui-components.png" alt="Panel Material UI Components" width="100%"/>
  </picture>
</a>

## Why Panel Material UI?

- **Consistent Look & Feel**
  Panel Material UI leverages Material UI’s design principles to give your Panel dashboards and applications a modern, cohesive style.

- **Easy Theming & Styling**
  Take control of your UI using Material UI’s theming concepts. Customize colors, typography, spacing, and more with minimal configuration. Quickly modify styling for one-off situations using the sx parameter or create global overrides via theme_config.

- **Seamless Dark Mode**
  Effortlessly toggle between light and dark palettes. Whether you want a permanently dark dashboard, a user-driven switch, or to match the system preference, Panel Material UI has you covered.

- **Familiar Panel API**
All components provide a similar API to native Panel widgets, ensuring a smooth developer experience. Pass parameters, bind widgets to reactive functions, and lay them out using Panel’s layout system.

- **Rich Component Set**
Access a growing collection of Material UI–inspired components (Buttons, Sliders, Cards, Dialogs, and more), all adapted to work with Panel. Spend less time building UI from scratch and more time showcasing your data.

- **Powerful Theming Inheritance**
  Define a theme at a parent level and let it automatically apply to child components without extra configuration, reducing repetitive code while maintaining consistent branding.

Panel Material UI is still fairly new—first released in May 2025. As with any young library, you might run into a few rough edges as we continue to shape and improve it.

We’re already using it in production, so development is active and updates are ongoing.

Thanks for your support as we (and maybe you?) keep making Panel Material UI even better!

Want to get involved? [Contribute on GitHub](https://github.com/panel-extensions/panel-material-ui/blob/main/DEVELOPER_GUIDE.md) or share your feedback, we’d love to hear from you.

## Installation

Install `panel-material-ui` via `pip`:

```bash
pip install panel-material-ui
```

or from conda-forge:

```bash
conda install -c conda-forge panel_material_ui
```

## Documentation

You can find the documentation [here](https://panel-material-ui.holoviz.org/).

## ❤️ Contributions

Contributions and co-maintainers are very welcome! Please submit issues or pull requests to the [GitHub repository](https://github.com/panel-extensions/panel-material-ui). Check out the [DEVELOPER_GUIDE](DEVELOPER_GUIDE.md) for more information.
